"use strict";
const QueryBuilder_1 = require("../query-builder/QueryBuilder");
class LazyRelationsWrapper {
    constructor(connection) {
        this.connection = connection;
    }
    wrap(object, relation) {
        const connection = this.connection;
        const index = "__" + relation.propertyName + "__";
        const loadIndex = "__load_" + relation.propertyName + "__";
        const resolveIndex = "__has_" + relation.propertyName + "__";
        Object.defineProperty(object, relation.propertyName, {
            get: function () {
                if (this[resolveIndex] === true)
                    return Promise.resolve(this[index]);
                if (this[loadIndex])
                    return this[loadIndex];
                const qb = new QueryBuilder_1.QueryBuilder(connection);
                if (relation.isManyToMany) {
                    qb.select(relation.propertyName)
                        .from(relation.type, relation.propertyName)
                        .innerJoin(relation.junctionEntityMetadata.table.name, relation.junctionEntityMetadata.name, `${relation.junctionEntityMetadata.name}.${relation.name}=:${relation.propertyName}Id`)
                        .setParameter(relation.propertyName + "Id", this[relation.referencedColumnName]);
                    this[loadIndex] = qb.getMany().then(results => {
                        this[index] = results;
                        this[resolveIndex] = true;
                        delete this[loadIndex];
                        return this[index];
                    }).catch(err => {
                        throw err;
                    });
                    return this[loadIndex];
                }
                else if (relation.isOneToMany) {
                    qb.select(relation.propertyName)
                        .from(relation.inverseRelation.entityMetadata.target, relation.propertyName)
                        .innerJoin(`${relation.propertyName}.${relation.inverseRelation.propertyName}`, relation.entityMetadata.targetName)
                        .andWhereInIds([relation.entityMetadata.getEntityIdMixedMap(this)]);
                    this[loadIndex] = qb.getMany().then(results => {
                        this[index] = results;
                        this[resolveIndex] = true;
                        delete this[loadIndex];
                        return this[index];
                    }).catch(err => {
                        throw err;
                    });
                    return this[loadIndex];
                }
                else {
                    if (relation.hasInverseSide) {
                        qb.select(relation.propertyName)
                            .from(relation.inverseRelation.entityMetadata.target, relation.propertyName)
                            .innerJoin(`${relation.propertyName}.${relation.inverseRelation.propertyName}`, relation.entityMetadata.targetName)
                            .andWhereInIds([relation.entityMetadata.getEntityIdMixedMap(this)]);
                    }
                    else {
                        // (ow) post.category<=>category.post
                        // loaded: category from post
                        // example: SELECT category.id AS category_id, category.name AS category_name FROM category category
                        //              INNER JOIN post Post ON Post.category=category.id WHERE Post.id=1
                        qb.select(relation.propertyName) // category
                            .from(relation.type, relation.propertyName) // Category, category
                            .innerJoin(relation.entityMetadata.target, relation.entityMetadata.name, `${relation.entityMetadata.name}.${relation.propertyName}=${relation.propertyName}.${relation.referencedColumn.propertyName}`)
                            .andWhereInIds([relation.entityMetadata.getEntityIdMixedMap(this)]);
                    }
                    this[loadIndex] = qb.getOne().then(result => {
                        this[index] = result;
                        this[resolveIndex] = true;
                        delete this[loadIndex];
                        return this[index];
                    }).catch(err => {
                        throw err;
                    });
                    return this[loadIndex];
                }
            },
            set: function (promise) {
                if (promise instanceof Promise) {
                    promise.then(result => {
                        this[index] = result;
                        this[resolveIndex] = true;
                    });
                }
                else {
                    this[index] = promise;
                    this[resolveIndex] = true;
                }
            },
            configurable: true
        });
    }
}
exports.LazyRelationsWrapper = LazyRelationsWrapper;

//# sourceMappingURL=LazyRelationsWrapper.js.map
